#ifndef _GSTREAMERBASEMM_H_
#define _GSTREAMERBASEMM_H_

//#include <gstreamerbasemm/bin.h>

#include <gstreamerbasemm/init.h>
#include <gstreamerbasemm/wrap_init.h>
#include <gstreamerbasemm/audioclock.h>
#include <gstreamerbasemm/colorbalance.h>
#include <gstreamerbasemm/colorbalancechannel.h>
#include <gstreamerbasemm/xoverlay.h>

#endif // _GSTREAMERBASEMM_H

